.. Ringo Printtemplate documentation master file, created by
   sphinx-quickstart on Sat Jan 31 13:13:56 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ringo Printtemplate's documentation!
===============================================

.. toctree::
   :maxdepth: 2

   main


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
